MacOSContainerControllerCreationParams class

Creation parameters for MacOSContainerController.

Annotations

Constructors

MacOSContainerControllerCreationParams(PlatformContainerControllerCreationParams params)
Creates macOS container controller parameters.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isClassSupported({TargetPlatform? platform}) bool
Checks whether this controller is available on platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited