MacOSStorageCreationParams class

Object specifying creation parameters for creating a MacOSStorage.

When adding additional fields make sure they can be null or have a default value to avoid breaking changes. See PlatformStorageCreationParams for more information.

Constructors

MacOSStorageCreationParams({required PlatformInAppWebViewController? controller, required WebStorageType webStorageType})
Creates a new MacOSStorageCreationParams instance.
MacOSStorageCreationParams.fromPlatformStorageCreationParams(PlatformStorageCreationParams params)
Creates a MacOSStorageCreationParams instance based on PlatformStorageCreationParams.
factory

Properties

controller → PlatformInAppWebViewController?
Controller used to interact with storage.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webStorageType → WebStorageType
The web storage type: window.sessionStorage or window.localStorage.
finalinherited

Methods

isClassSupported({TargetPlatform? platform}) bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
inherited
isPropertySupported(PlatformStorageCreationParamsProperty property, {TargetPlatform? platform}) bool
Check if the given property is supported by the defaultTargetPlatform or a specific platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited